Package: jsutils
Title: 'JavaScript' Utilities for 'R'
Version: 0.3.0
Authors@R: 
    person(c("Andrew", "R."), "Johnson", , "andrew.johnson@arjohnsonau.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7000-8065"))
Description: A collection of popular/useful JavaScript utilities, including the
    terser minifier, sass compiler, typescript transpiler, and more.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: QuickJSR (>= 1.8.1)
URL: https://github.com/andrjohns/jsutils,
        https://andrjohns.github.io/jsutils/
NeedsCompilation: no
Packaged: 2026-05-17 05:34:45 UTC; andrew
Author: Andrew R. Johnson [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7000-8065>)
Maintainer: Andrew R. Johnson <andrew.johnson@arjohnsonau.com>
Repository: CRAN
Date/Publication: 2026-05-17 06:00:02 UTC
Built: R 4.5.2; ; 2026-05-17 06:30:03 UTC; unix
