.ESPRIMA_VERSION <- "4.0.1"
.SASS_VERSION <- "1.99.0"
.TERSER_VERSION <- "5.47.1"
.TYPESCRIPT_VERSION <- "6.0.3"

#' Get versions of bundled JavaScript libraries
#'
#' This function returns the versions of the bundled JavaScript libraries used in the package.
#'
#' @return A named list with the versions of Esprima, sass.js, Terser, and TypeScript.
#' @examples
#' js_versions()
#' @export
js_versions <- function() {
  list(
    esprima = .ESPRIMA_VERSION,
    sass = .SASS_VERSION,
    terser = .TERSER_VERSION,
    typescript = .TYPESCRIPT_VERSION
  )
}
